<?php
namespace Ep\Wp\View;

use Options\OptionsManager;

/**
 * Class OptionsView
 *
 * @package Options\View
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link http://gitlab.ep.local/ep-framework/wordpress
 */
class OptionsView extends AbstractView
{
    /** @var OptionsManager */
    private $manager;

    /**
     * Konstruktor.
     *
     * @param OptionsManager $manager
     */
    public function __construct(OptionsManager $manager)
    {
        $this->manager = $manager;
    }

    /**
     * Dodaje akcije i filtere u WordPress.
     */
    public function init(): void
    {
        add_action('admin_menu', [$this, 'admin_menu']);
    }

    /**
     * Dodaje stavku u administracijski izbornik.
     */
    public function admin_menu(): void
    {
        if (!function_exists('add_menu_page')) {
            throw new \RuntimeException('Ne možemo dodavati stavke u admin izbornik prije nego što je WordPress dostupan');
        }

        add_menu_page(
            'Webshop Postavke',
            'Postavke',
            'manage_options',
            'webshop-options',
            [$this, 'output'],
            'dashicons-forms',
            '2.0'
        );
    }

    /**
     * Renderira view.
     *
     * @return string
     */
    public function render(): string
    {
        return $this->renderer->render('@wp/admin/options.html.twig', [
            'forms' => $this->manager->getAllForms(),
        ]);
    }
}