<?php
namespace EpTest\Wp\Plugin\Core;

use Ep\View\Helper\AssetUrl;
use Ep\Wp\Test\AbstractWordPressTest;
use Ep\Wp\Plugin\Core\Assets;
use PHPUnit\Framework\MockObject\MockObject;

final class AssetsTest extends AbstractWordPressTest
{
    public function testPluginIsRegistered()
    {
        $plugin = $this->getPlugin('wp.core.assets');
        $this->assertInstanceOf(Assets::class, $plugin);
    }

    public function testPluginIsProxyingToAssetUrlHelper()
    {
        /** @var AssetUrl|MockObject $helper */
        $helper = @$this->createPartialMock(AssetUrl::class, [
            '__invoke',
        ]);

        $plugin = new Assets($helper);
        $plugin->attach();

        $helper
            ->expects($this->once())
            ->method('__invoke')
            ->willReturn('/replaced');

        $value = apply_filters('ep_asset_url', 'ignore');
        $this->assertStringEndsWith('/replaced', $value);
    }

    public function testPluginIsProcessingScriptsAndStyles()
    {
        /** @var AssetUrl|MockObject $helper */
        $helper = $this->createPartialMock(AssetUrl::class, [
            '__invoke',
        ]);

        $plugin = new Assets($helper);
        $plugin->attach();

        $helper
            ->expects($this->exactly(2))
            ->method('__invoke')
            ->withConsecutive(
                [$this->equalTo('/test.js')],
                [$this->equalTo('/test.css')]
            )
            ->willReturnOnConsecutiveCalls(
                '/test-replaced.js',
                '/test-replaced.css'
            );

        wp_enqueue_style('test', '/test.css', [], 'ep-asset');
        wp_enqueue_script('test', '/test.js', [], 'ep-asset', true);

        ob_start();
        wp_head();
        $head = ob_get_clean();

        $this->assertRegExp('#<link.+href=.+/test-replaced.css#', $head);
        $this->assertNotRegExp('#<script.+src=.+/test-replaced.js#', $head);

        ob_start();
        wp_footer();
        $footer = ob_get_clean();

        $this->assertRegExp('#<script.+src=.+/test-replaced.js#', $footer);
    }
}
